<?php

namespace Luticate\Auth\Controller;

use Luticate\Auth\DBO\LuticateUsersDbo;
use Luticate\Utils\LuController;
use Luticate\Auth\Business\LuticatePermissionsBusiness;
use Luticate\Auth\DBO\LuticatePermissionsDbo;

class LuticatePermissionsController extends LuController {
    protected function getBusiness()
    {
        return new LuticatePermissionsBusiness();
    }

    /**
     * Get the effective permission for a user
     * @param $user_id int The user id
     * @param $permission_name string The permission name
     * @return LuticatePermissionsDbo
     */
    public function getEffectivePermission($user_id, $permission_name)
    {
        return LuticatePermissionsBusiness::getEffectivePermission($user_id, $permission_name);
    }

    /**
     * Get the effective permission for the logged user
     * @param $_user LuticateUsersDbo Logged user
     * @param $permission_name string The permission name
     * @return LuticatePermissionsDbo
     */
    public function getEffectivePermissionMe($_user, $permission_name)
    {
        return LuticatePermissionsBusiness::getEffectivePermissionMe($_user, $permission_name);
    }

    /**
     * Get a permission
     * @param $permission_name string The permission name
     * @return \Luticate\Utils\LuDbo
     */
    public function get($permission_name)
    {
        return LuticatePermissionsBusiness::get($permission_name);
    }

    /**
     * Add a permission
     * @param $permission_name string The permission name
     * @param $permission_value bool The default permission value
     * @return bool
     */
    public function add($permission_name, $permission_value)
    {
        return LuticatePermissionsBusiness::add($permission_name, $permission_value);
    }

    /**
     * Remove a permission
     * @param $permission_name string The permission name
     * @return bool
     */
    public function del($permission_name)
    {
        return LuticatePermissionsBusiness::del($permission_name);
    }

    /**
     * Edit the default permission value
     * @param $permission_name string The permission name
     * @param $permission_value bool The default permission value
     * @return bool
     */
    public function edit($permission_name, $permission_value)
    {
        return LuticatePermissionsBusiness::edit($permission_name, $permission_value);
    }
}