<?php

namespace Luticate\Auth\Controller;

use Luticate\Utils\LuController;
use Luticate\Auth\Business\LuticateUsersBusiness;
use Luticate\Auth\DBO\LuticateUsersDbo;

class LuticateUsersController extends LuController {
    protected function getBusiness()
    {
        return new LuticateUsersBusiness();
    }

    /**
     * Login the user
     * @param $username string The user username
     * @param $password string The user password
     * @return LuticateUsersDbo
     */
    public function login($username, $password)
    {
        return LuticateUsersBusiness::login($username, $password);
    }

    /**
     * Logout the logged user
     * @param $_user LuticateUsersDbo The logged user
     * @return bool
     */
    public function logout($_user)
    {
        return LuticateUsersBusiness::logout($_user);
    }

    /**
     * Get a user by its id
     * @param $user_id int The user id
     * @return \Luticate\Utils\LuDbo
     */
    public function getLightById($user_id)
    {
        return LuticateUsersBusiness::getLightById($user_id);
    }

    /**
     * Get all users
     * @param int $page The page number, 0 based
     * @param int $perPage The number of items per page
     * @return array
     */
    public function getAllLight($page = 0, $perPage = PHP_INT_MAX)
    {
        return LuticateUsersBusiness::getAllLight($page, $perPage);
    }

    /**
     * Add a user
     * @param $username string The new user username
     * @param $email string The new user email
     * @param $password string The new user plain text password
     * @return int
     */
    public function add($username, $email, $password)
    {
        return LuticateUsersBusiness::add($username, $email, $password);
    }

    /**
     * Delete a user by its id
     * @param $user_id int The user id
     * @return bool
     */
    public function del($user_id)
    {
        return LuticateUsersBusiness::deleteById($user_id);
    }

    /**
     * Edit the user details
     * @param $email string The new user amil
     * @param $user_id int The user id
     * @param $firstname string The user firstname
     * @param $lastname string The user lastname
     * @return bool
     */
    public function edit($email, $firstname, $lastname, $user_id)
    {
        return LuticateUsersBusiness::edit($user_id, $firstname, $lastname, $email);
    }

    /**
     * Edit the logged user email
     * @param $email string The new user email
     * @param $_user LuticateUsersDbo The logged user
     * @return bool
     */
    public function editMe($email, $_user)
    {
        return LuticateUsersBusiness::edit($_user->getId(), $email);
    }

    /**
     * Edit the password for a user
     * @param $password string The new plain text password
     * @param $user_id int The user id
     * @return bool
     */
    public function setPassword($password, $user_id)
    {
        return LuticateUsersBusiness::setPassword($user_id, $password);
    }

    /**
     * Edit the password for the logged user
     * @param $password string The new plain text password
     * @param $oldPassword string The old plain text password
     * @param $_user LuticateUsersDbo The logged user
     * @return bool
     */
    public function setPasswordMe($password, $oldPassword, $_user)
    {
        return LuticateUsersBusiness::setPasswordMe($password, $oldPassword, $_user);
    }
}